==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/thyra/src/support/operator_vector/adapter_support/Thyra_ScalarProdBase_def.hpp <==
// @HEADER
// ***********************************************************************
// 
//    Thyra: Interfaces and Support for Abstract Numerical Algorithms
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// ***********************************************************************
// @HEADER

#ifndef THYRA_SCALAR_PROD_BASE_DEF_HPP
#define THYRA_SCALAR_PROD_BASE_DEF_HPP

#include "Thyra_ScalarProdBase_decl.hpp"
#include "Thyra_EuclideanLinearOpBase.hpp"
#include "Thyra_AssertOp.hpp"


namespace Thyra {


// Protected virtual functions


template<class Scalar>
Scalar ScalarProdBase<Scalar>::scalarProdImpl(
  const VectorBase<Scalar>& x, const VectorBase<Scalar>& y
  ) const
{
  Tuple<Scalar,1> scalarProds_out;
  this->scalarProds(x, y, scalarProds_out());
  return scalarProds_out[0];
}


} // end namespace Thyra


#endif  // THYRA_SCALAR_PROD_BASE_DEF_HPP

==> trilinos_10.4.0.dfsg.orig.tar.gz: trilinos-10.4.0.dfsg.orig/packages/thyra/src/support/operator_vector/adapter_support/Thyra_ScalarProdBase_def.hpp <==
// @HEADER
// ***********************************************************************
// 
//    Thyra: Interfaces and Support for Abstract Numerical Algorithms
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// ***********************************************************************
// @HEADER

#ifndef THYRA_SCALAR_PROD_BASE_DEF_HPP
#define THYRA_SCALAR_PROD_BASE_DEF_HPP

#include "Thyra_ScalarProdBase_decl.hpp"
#include "Thyra_VectorBase.hpp"


namespace Thyra {


// Protected virtual functions


template<class Scalar>
Scalar ScalarProdBase<Scalar>::scalarProdImpl(
  const VectorBase<Scalar>& x, const VectorBase<Scalar>& y
  ) const
{
  Tuple<Scalar,1> scalarProds_out;
  this->scalarProds(x, y, scalarProds_out());
  return scalarProds_out[0];
}


} // end namespace Thyra


#endif  // THYRA_SCALAR_PROD_BASE_DEF_HPP
